/*
 * Asterisk -- A telephony toolkit for Linux.
 *
 * DTGET application
 * 
 */

#include <asterisk/file.h>
#include <asterisk/logger.h>
#include <asterisk/channel.h>
#include <asterisk/pbx.h>
#include <asterisk/module.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <pthread.h>
#include <asterisk/indications.h>
#include <asterisk/app.h>

static char *tdesc = "Dialtone Get Digit Application";
static char *app = "DTGET";
static char *synopsis = "DTGET([x][|var][|timeout])\n"
"Play a dialtone and collect 'x' digits setting the resulting\n"
"string to 'var' waiting 'timeout' seconds between each digit.\n"
"a '*' will reinit the dial tone and start over\n"
"the defaults are x=10 var=DTGET and timeout=10\n";

STANDARD_LOCAL_USER;

LOCAL_USER_DECL;

#define MAX_DIG 128


static int dtget_exec(struct ast_channel *chan, void *data)
{
	int res=0;
	struct localuser *u;
	char collect[MAX_DIG];
	char *buf;
	char *digits=NULL,*var=NULL,*timeout=NULL;
	int to = 0;
	int total = 0;

	
	ast_answer(chan);
	memset(collect,0,MAX_DIG);
	LOCAL_USER_ADD(u);
	buf = ast_strdupa(data);

	digits = buf;
	if((var=strchr(digits,'|'))) {
		*var = '\0';
		var++;
		if((timeout=strchr(var,'|'))) {
			*timeout = '\0';		
			timeout++;
		}
	}
	if(digits)
		total = atoi(digits);
	if(timeout)
		to = atoi(timeout);

	if(!to)
		to = 10;
	if(!total)
		total = 10;
	if(!var)
		var = "DTGET";

	ast_dtget(chan, collect, MAX_DIG, total, to);
	pbx_builtin_setvar_helper(chan,var,collect);
	LOCAL_USER_REMOVE(u);
	return res;
}

int unload_module(void)
{
	STANDARD_HANGUP_LOCALUSERS;
	return ast_unregister_application(app);
}

int load_module(void)
{
	return ast_register_application(app, dtget_exec, synopsis, tdesc);
}

char *description(void)
{
	return tdesc;
}

int usecount(void)
{
	int res;
	STANDARD_USECOUNT(res);
	return res;
}

char *key()
{
	return ASTERISK_GPL_KEY;
}
